/* $Id$ */

#ifndef __rxml_STATE__
#define __rxml_STATE__

extern VALUE cXMLState;
extern VALUE LIBXML_STATE;

void ruby_init_state(void);

#endif
